@@ -1,7 +1,9 @@
 package Progress::Any::Output;
 
-our $DATE = '2018-03-26'; # DATE
-our $VERSION = '0.213'; # VERSION
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2020-06-21'; # DATE
+our $DIST = 'Progress-Any'; # DIST
+our $VERSION = '0.215'; # VERSION
 
 use 5.010001;
 use strict;
@@ -20,11 +22,19 @@ sub _set_or_add {
 
     my $opts;
     if (@_ && ref($_[0]) eq 'HASH') {
-        $opts = shift;
+        $opts = {%{shift()}}; # shallow copy
     } else {
         $opts = {};
     }
 
+    # allow adding options via -name => val syntax, for ease in using via -M in
+    # one-liners.
+    while (1) {
+        last unless @_ && $_[0] =~ /\A-(.+)/;
+        $opts->{$1} = $_[1];
+        splice @_, 0, 2;
+    }
+
     my $output = shift or die "Please specify output name";
     $output =~ /\A(?:\w+(::\w+)*)?\z/ or die "Invalid output syntax '$output'";
 
@@ -45,11 +55,6 @@ sub _set_or_add {
         push @{ $Progress::Any::outputs{$task} }, $outputo;
     }
 
-    if ($outputo->can("output_data")) {
-        my $odata = $outputo->output_data;
-        $Progress::Any::output_data{"$outputo"} = $odata;
-    }
-
     $outputo;
 }
 
@@ -78,7 +83,7 @@ Progress::Any::Output - Assign output to progress indicators
 
 =head1 VERSION
 
-This document describes version 0.213 of Progress::Any::Output (from Perl distribution Progress-Any), released on 2018-03-26.
+This document describes version 0.215 of Progress::Any::Output (from Perl distribution Progress-Any), released on 2020-06-21.
 
 =head1 SYNOPSIS
 
@@ -102,6 +107,10 @@ or:
 
 To assign output to a certain (sub)task:
 
+ use Progress::Any::Output -task => "main.download", 'TermMessage';
+
+or:
+
  use Progress::Any::Output;
  Progress::Any::Output->set({task=>'main.download'}, 'TermMessage');
 
@@ -154,7 +163,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2015, 2014, 2013, 2012 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
